@@ -37,7 +37,7 @@ public:
 
   bool                allocate(uint64_t size, int flags = 0) const;
 
-  MemoryChunk         create_padding_chunk(uint32_t length, int prot, int flags) const;
+  static MemoryChunk  create_padding_chunk(uint32_t length, int prot, int flags);
   MemoryChunk         create_chunk(uint64_t offset, uint32_t length, int prot, int flags) const;
 
   fd_type             fd() const                                        { return m_fd; }
@@ -50,7 +50,7 @@ private:
   fd_type             m_fd{invalid_fd};
 };
 
-}
+} // namespace torrent
 
 #endif
 
