@@ -120,6 +120,6 @@ private:
   uint32_t            m_position;
 };
 
-}
+} // namespace torrent
 
 #endif  
