@@ -22,6 +22,7 @@
 #include "torrent/download/download_manager.h"
 #include "torrent/download_info.h"
 #include "torrent/exceptions.h"
+#include "torrent/net/network_config.h"
 #include "torrent/peer/connection_list.h"
 #include "torrent/peer/peer.h"
 #include "torrent/peer/peer_info.h"
@@ -93,16 +94,16 @@ DownloadMain::~DownloadMain() {
 
 void
 DownloadMain::post_initialize() {
-  auto tracker_controller = std::make_shared<TrackerController>(m_tracker_list);
+  auto tc = std::make_shared<TrackerController>(m_tracker_list);
 
-  m_tracker_list->slot_success()          = [tracker_controller](const auto& t, auto al) { return tracker_controller->receive_success(t, al); };
-  m_tracker_list->slot_failure()          = [tracker_controller](const auto& t, const auto& str) { tracker_controller->receive_failure(t, str); };
-  m_tracker_list->slot_scrape_success()   = [tracker_controller](const auto& t) { tracker_controller->receive_scrape(t); };
-  m_tracker_list->slot_tracker_enabled()  = [tracker_controller](const auto& t) { tracker_controller->receive_tracker_enabled(t); };
-  m_tracker_list->slot_tracker_disabled() = [tracker_controller](const auto& t) { tracker_controller->receive_tracker_disabled(t); };
+  m_tracker_list->slot_success()          = [tc](const auto& t, auto al)         { return tc->receive_success(t, al); };
+  m_tracker_list->slot_failure()          = [tc](const auto& t, const auto& str) { tc->receive_failure(t, str); };
+  m_tracker_list->slot_scrape_success()   = [tc](const auto& t)                  { tc->receive_scrape(t); };
+  m_tracker_list->slot_new_peers()        = [tc](auto al)                        { return tc->receive_new_peers(al); };
+  m_tracker_list->slot_tracker_enabled()  = [tc](const auto& t)                  { tc->receive_tracker_enabled(t); };
+  m_tracker_list->slot_tracker_disabled() = [tc](const auto& t)                  { tc->receive_tracker_disabled(t); };
 
-  // TODO: Move tracker list to manager, and add the proper barrier for slots.
-  m_tracker_controller = thread_tracker()->tracker_manager()->add_controller(info(), std::move(tracker_controller));
+  m_tracker_controller = thread_tracker()->tracker_manager()->add_controller(info(), std::move(tc));
 }
 
 std::pair<ThrottleList*, ThrottleList*>
@@ -283,7 +284,10 @@ DownloadMain::receive_corrupt_chunk(PeerInfo* peerInfo) {
 }
 
 void
-DownloadMain::add_peer(const rak::socket_address& sa) {
+DownloadMain::add_peer(const sockaddr* sa) {
+  if (config::network_config()->is_block_outgoing())
+    return;
+
   m_slot_start_handshake(sa, this);
 }
 
@@ -301,14 +305,17 @@ DownloadMain::receive_connect_peers() {
     alist->clear();
   }
 
+  if (config::network_config()->is_block_outgoing())
+    return;
+
   while (!peer_list()->available_list()->empty() &&
          manager->connection_manager()->can_connect() &&
          connection_list()->size() < connection_list()->min_size() &&
          connection_list()->size() + m_slot_count_handshakes(this) < connection_list()->max_size()) {
-    rak::socket_address sa = peer_list()->available_list()->pop_random();
+    auto sa = peer_list()->available_list()->pop_random();
 
-    if (connection_list()->find(sa.c_sockaddr()) == connection_list()->end())
-      m_slot_start_handshake(sa, this);
+    if (connection_list()->find(&sa.sa) == connection_list()->end())
+      m_slot_start_handshake(&sa.sa, this);
   }
 }
 
@@ -368,10 +375,15 @@ DownloadMain::do_peer_exchange() {
 
   for (auto& connection : *m_connectionList) {
     auto pcb = connection->m_ptr();
-    auto sa  = rak::socket_address::cast_from(pcb->peer_info()->socket_address());
+    auto sa  = pcb->peer_info()->socket_address();
 
-    if (pcb->peer_info()->listen_port() != 0 && sa->family() == rak::socket_address::af_inet)
-      current.emplace_back(sa->sa_inet()->address_n(), htons(pcb->peer_info()->listen_port()));
+    if (pcb->peer_info()->listen_port() != 0 && sa->sa_family == AF_INET) {
+      // The reinterpret_cast requires const in push_back, while not in emplace_back.
+      //
+      // Might be the cause of corrupt address values in rtorrent-docker tests.
+      // current.emplace_back(reinterpret_cast<sockaddr_in*>(&sa)->sin_addr.s_addr, htons(pcb->peer_info()->listen_port()));
+      current.push_back(SocketAddressCompact(reinterpret_cast<const sockaddr_in*>(sa)->sin_addr.s_addr, htons(pcb->peer_info()->listen_port())));
+    }
 
     if (!pcb->extensions()->is_remote_supported(ProtocolExtension::UT_PEX))
       continue;
