@@ -36,15 +36,10 @@
 
 #include "config.h"
 
-#include <algorithm>
-#include <functional>
-
 #include "socket_set.h"
 
 namespace torrent {
 
-const SocketSet::size_type SocketSet::npos;
-
 inline void
 SocketSet::_replace_with_last(size_type idx) {
   while (!base_type::empty() && base_type::back() == NULL)
@@ -80,4 +75,4 @@ SocketSet::reserve(size_t openMax) {
   base_type::reserve(openMax);
 }
 
-}
+} // namespace torrent
