@@ -85,13 +85,13 @@ HandshakeManager::erase_download(DownloadMain* info) {
 void
 HandshakeManager::add_incoming(int fd, const sockaddr* sa) {
   if (!manager->connection_manager()->can_connect()) {
-    LT_LOG_SA(sa, "rejected outgoing connection: fd:%i : rejected by connection manager", fd);
+    LT_LOG_SA(sa, "rejected incoming connection: fd:%i : rejected by connection manager", fd);
     fd_close(fd);
     return;
   }
 
   if (!manager->connection_manager()->filter(sa)) {
-    LT_LOG_SA(sa, "rejected outgoing connection: fd:%i : filtered", fd);
+    LT_LOG_SA(sa, "rejected incoming connection: fd:%i : filtered", fd);
     fd_close(fd);
     return;
   }
@@ -121,7 +121,16 @@ HandshakeManager::add_outgoing(const sockaddr* sa, DownloadMain* download) {
       !manager->connection_manager()->filter(sa))
     return;
 
-  create_outgoing(sa, download, config::network_config()->encryption_options());
+  auto encryption_options = config::network_config()->encryption_options();
+
+  if (download->info()->is_meta_download()) {
+    encryption_options &= ~net::NetworkConfig::encryption_try_outgoing;
+    encryption_options &= ~net::NetworkConfig::encryption_require;
+    encryption_options &= ~net::NetworkConfig::encryption_require_RC4;
+    encryption_options &= ~net::NetworkConfig::encryption_enable_retry;
+  }
+
+  create_outgoing(sa, download, encryption_options);
 }
 
 void
@@ -168,7 +177,9 @@ HandshakeManager::create_outgoing(const sockaddr* sa, DownloadMain* download, in
   else
     message = ConnectionManager::handshake_outgoing;
 
-  LT_LOG_SAP(connect_address, "created outgoing connection: fd:%i encryption:%x message:%x", fd, encryption_options, message);
+  LT_LOG_SAP(connect_address, "created outgoing connection: fd:%i address:%s encryption:%x message:%x",
+             fd, sa_pretty_str(sa).c_str(), encryption_options, message);
+
   manager->connection_manager()->inc_socket_count();
 
   auto handshake = std::make_unique<Handshake>(fd, this, encryption_options);
