@@ -80,6 +80,16 @@ Block::~Block() {
   delete m_failedList;
 }
 
+bool
+Block::is_finished() const {
+  return m_leader != nullptr && m_leader->is_finished();
+}
+
+bool
+Block::is_transfering() const {
+  return m_leader != nullptr && !m_leader->is_finished();
+}
+
 BlockTransfer*
 Block::insert(PeerInfo* peerInfo) {
   if (find_queued(peerInfo) || find_transfer(peerInfo))
@@ -87,18 +97,17 @@ Block::insert(PeerInfo* peerInfo) {
 
   m_notStalled++;
 
-  auto itr = m_queued.insert(m_queued.end(), new BlockTransfer());
+  auto block = new BlockTransfer;
+  block->set_peer_info(peerInfo);
+  block->set_block(this);
+  block->set_piece(m_piece);
+  block->set_state(BlockTransfer::STATE_QUEUED);
+  block->set_request_time(this_thread::cached_seconds().count());
+  block->set_position(0);
+  block->set_stall(0);
+  block->set_failed_index(BlockFailed::invalid_index);
 
-  (*itr)->set_peer_info(peerInfo);
-  (*itr)->set_block(this);
-  (*itr)->set_piece(m_piece);
-  (*itr)->set_state(BlockTransfer::STATE_QUEUED);
-  (*itr)->set_request_time(this_thread::cached_seconds().count());
-  (*itr)->set_position(0);
-  (*itr)->set_stall(0);
-  (*itr)->set_failed_index(BlockFailed::invalid_index);
-
-  return (*itr);
+  return m_queued.emplace_back(block);
 }
   
 void
@@ -183,7 +192,7 @@ Block::transfering(BlockTransfer* transfer) {
     throw internal_error("Block::transfering(...) not queued.");
 
   m_queued.erase(itr);
-  m_transfers.insert(m_transfers.end(), transfer);
+  m_transfers.push_back(transfer);
 
   // If this block already has an active transfer, make this transfer
   // skip the piece. If this transfer gets ahead of the currently
@@ -281,6 +290,14 @@ Block::transfer_dissimilar(BlockTransfer* transfer) {
   transfer->set_block(NULL);
 }
 
+void
+Block::stalled(BlockTransfer* transfer) {
+  if (!transfer->is_valid())
+    return;
+
+  transfer->block()->stalled_transfer(transfer);
+}
+
 void
 Block::stalled_transfer(BlockTransfer* transfer) {
   if (transfer->stall() == 0) {
@@ -372,7 +389,7 @@ Block::invalidate_transfer(BlockTransfer* transfer) {
 
 void
 Block::remove_erased_transfers() {
-  auto split = std::stable_partition(m_transfers.begin(), m_transfers.end(), [](auto block) { return !block->is_erased(); });
+  auto split = std::stable_partition(m_transfers.begin(), m_transfers.end(), std::not_fn(std::mem_fn(&BlockTransfer::is_erased)));
 
   std::for_each(split, m_transfers.end(), [this](auto block) { invalidate_transfer(block); });
   m_transfers.erase(split, m_transfers.end());
@@ -426,4 +443,4 @@ Block::find_transfer(const PeerInfo* p) const {
     return *itr;
 }
 
-}
+} // namespace torrent
