@@ -39,7 +39,6 @@
 #include <algorithm>
 #include <functional>
 
-#include "block_transfer.h"
 #include "block_list.h"
 #include "exceptions.h"
 
@@ -82,4 +81,4 @@ BlockList::do_all_failed() {
   std::for_each(begin(), end(), std::mem_fn(&Block::retry_transfer));
 }
 
-}
+} // namespace torrent
