@@ -1,30 +1,17 @@
 #include "config.h"
 
 #include <cassert>
-#include <rak/error_number.h>
 #include <rak/file_stat.h>
 
-#include "data/memory_chunk.h"
 #include "data/socket_file.h"
-#include "torrent/exceptions.h"
 
+#include "exceptions.h"
 #include "file.h"
 #include "file_manager.h"
 #include "manager.h"
 
 namespace torrent {
 
-const int File::flag_active;
-const int File::flag_create_queued;
-const int File::flag_resize_queued;
-const int File::flag_fallocate;
-const int File::flag_previously_created;
-
-const int File::flag_prioritize_first;
-const int File::flag_prioritize_last;
-
-const int File::flag_attr_padding;
-
 File::~File() {
   assert((is_padding() || !is_open()) && "File::~File() called on an open file.");
 }
@@ -138,7 +125,7 @@ File::set_match_depth(File* left, File* right) {
 }
 
 bool
-File::resize_file() {
+File::resize_file() const {
   if (is_padding())
     return true;
 
@@ -161,4 +148,4 @@ File::resize_file() {
   return true;
 }
 
-}
+} // namespace torrent
