@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-
+#include "torrent/download_info.h"
 #include "torrent/exceptions.h"
 
 #include "download/download_wrapper.h"
@@ -113,4 +113,4 @@ DownloadManager::find_main_obfuscated(const char* hash) {
     return (*itr)->main();
 }
 
-}
+} // namespace torrent
