@@ -5,11 +5,12 @@
 #include <limits>
 #include <numeric>
 
-#include "torrent/exceptions.h"
-#include "torrent/download/choke_group.h"
-#include "torrent/utils/log.h"
 #include "download/download_main.h"
 #include "protocol/peer_connection_base.h"
+#include "torrent/download/choke_group.h"
+#include "torrent/download_info.h"
+#include "torrent/exceptions.h"
+#include "torrent/utils/log.h"
 
 #include "choke_queue.h"
 #include "resource_manager.h"
@@ -137,12 +138,12 @@ ResourceManager::push_group(const std::string& name) {
 }
 
 ResourceManager::iterator
-ResourceManager::find(DownloadMain* d) {
+ResourceManager::find(const DownloadMain* d) {
   return std::find_if(begin(), end(), [d](value_type e) { return d == e.download(); });
 }
 
 ResourceManager::iterator
-ResourceManager::find_throw(DownloadMain* d) {
+ResourceManager::find_throw(const DownloadMain* d) {
   auto itr = find(d);
 
   if (itr == end())
@@ -187,7 +188,7 @@ ResourceManager::group_index_of(const std::string& name) {
 
 void
 ResourceManager::set_priority(iterator itr, uint16_t pri) {
-  LT_LOG_ITR("set priority: %" PRIu16, 0)
+  LT_LOG_ITR("set priority: %" PRIu16, 0);
 
   itr->set_priority(pri);
 }
@@ -265,7 +266,7 @@ ResourceManager::receive_download_unchoke(int num) {
 }
 
 int
-ResourceManager::retrieve_upload_can_unchoke() {
+ResourceManager::retrieve_upload_can_unchoke() const {
   if (m_maxUploadUnchoked == 0)
     return std::numeric_limits<int>::max();
 
@@ -273,7 +274,7 @@ ResourceManager::retrieve_upload_can_unchoke() {
 }
 
 int
-ResourceManager::retrieve_download_can_unchoke() {
+ResourceManager::retrieve_download_can_unchoke() const {
   if (m_maxDownloadUnchoked == 0)
     return std::numeric_limits<int>::max();
 
@@ -372,4 +373,4 @@ ResourceManager::balance_unchoked(unsigned int weight, unsigned int max_unchoked
   return change;
 }
 
-}
+} // namespace torrent
