@@ -48,6 +48,11 @@ TrackerHttp::~TrackerHttp() {
   this_thread::scheduler()->erase(&m_delay_scrape);
 }
 
+tracker_enum
+TrackerHttp::type() const {
+  return TRACKER_HTTP;
+}
+
 bool
 TrackerHttp::is_busy() const {
   return m_data != nullptr;
@@ -62,8 +67,6 @@ TrackerHttp::send_event(tracker::TrackerState::event_enum new_state) {
 
   lock_and_set_latest_event(new_state);
 
-  m_get.try_wait_for_close();
-
   // TODO: Move to network config and add simple retry other AF logic.
 
   // TODO: We need to handle retry logic here, not in http stack, as we need to change the bind
@@ -97,6 +100,8 @@ TrackerHttp::send_event(tracker::TrackerState::event_enum new_state) {
   auto request_url = request_announce_url(new_state, params, family);
 
   m_data = std::make_unique<std::stringstream>();
+
+  m_get.try_wait_for_close();
   m_get.reset(request_url, m_data);
 
   // TODO: Should bind address here...
@@ -253,11 +258,6 @@ TrackerHttp::close() {
   close_directly();
 }
 
-tracker_enum
-TrackerHttp::type() const {
-  return TRACKER_HTTP;
-}
-
 void
 TrackerHttp::close_directly() {
   if (m_data == nullptr) {
@@ -417,8 +417,13 @@ TrackerHttp::process_success(const Object& object) {
       state().m_scrape_downloaded = std::max<int64_t>(object.get_key_value("downloaded"), 0);
   }
 
-  if (!object.has_key("peers") && !object.has_key("peers6"))
-    return receive_failed("No peers returned");
+  if (!object.has_key("peers") && !object.has_key("peers6")) {
+    if (state().latest_event() != tracker::TrackerState::EVENT_STOPPED)
+      return receive_failed("No peers returned");
+
+    close_directly();
+    m_slot_success(AddressList());
+  }
 
   AddressList l;
 
