@@ -9,26 +9,34 @@
 #include <openssl/dh.h>
 #include <openssl/bn.h>
 
-namespace torrent {
-
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 
-static auto dh_get(const DiffieHellman::dh_ptr& dh) { return static_cast<DH*>(dh.get()); }
+namespace {
+void
+dh_free(void* dh) { DH_free(static_cast<DH*>(dh)); }
 
-static bool
-dh_set_pg(DiffieHellman::dh_ptr& dh, BIGNUM* dh_p, BIGNUM* dh_g) {
+auto
+dh_get(const torrent::DiffieHellman::dh_ptr& dh) { return static_cast<DH*>(dh.get()); }
+
+bool
+dh_set_pg(torrent::DiffieHellman::dh_ptr& dh, BIGNUM* dh_p, BIGNUM* dh_g) {
   return DH_set0_pqg(static_cast<DH*>(dh.get()), dh_p, nullptr, dh_g);
 }
 
-static const BIGNUM* dh_get_pub_key(const DiffieHellman::dh_ptr& dh) {
+const BIGNUM*
+dh_get_pub_key(const torrent::DiffieHellman::dh_ptr& dh) {
   const BIGNUM *pub_key;
   DH_get0_key(dh_get(dh), &pub_key, nullptr);
   return pub_key;
 }
 
+} // namespace
+
+namespace torrent {
+
 DiffieHellman::DiffieHellman(const unsigned char *prime, int primeLength,
                              const unsigned char *generator, int generatorLength) :
-  m_dh(DH_new(), [](auto dh){ DH_free(static_cast<DH*>(dh)); }) {
+  m_dh(DH_new(), &dh_free) {
 
   BIGNUM* dh_p = BN_bin2bn(prime, primeLength, nullptr);
   BIGNUM* dh_g = BN_bin2bn(generator, generatorLength, nullptr);
@@ -37,7 +45,7 @@ DiffieHellman::DiffieHellman(const unsigned char *prime, int primeLength,
     throw internal_error("Could not generate Diffie-Hellman parameters");
 
   DH_generate_key(dh_get(m_dh));
-};
+}
 
 bool
 DiffieHellman::is_valid() const {
@@ -54,7 +62,7 @@ DiffieHellman::compute_secret(const unsigned char *pubkey, unsigned int length)
   BN_free(k);
 
   return m_size != -1;
-};
+}
 
 void
 DiffieHellman::store_pub_key(unsigned char* dest, unsigned int length) {
@@ -66,4 +74,4 @@ DiffieHellman::store_pub_key(unsigned char* dest, unsigned int length) {
     BN_bn2bin(pub_key, dest + length - BN_num_bytes(pub_key));
 }
 
-};
+} // namespace torrent
