@@ -1,21 +1,18 @@
-#include <cppunit/extensions/HelperMacros.h>
+#include "helpers/test_fixture.h"
 
-#include "protocol/request_list.h"
+class test_queue_buckets : public test_fixture {
+  CPPUNIT_TEST_SUITE(test_queue_buckets);
 
-class TestQueueBuckets : public CppUnit::TestFixture {
-  CPPUNIT_TEST_SUITE(TestQueueBuckets);
   CPPUNIT_TEST(test_basic);
   CPPUNIT_TEST(test_erase);
   CPPUNIT_TEST(test_find);
 
   CPPUNIT_TEST(test_destroy_range);
   CPPUNIT_TEST(test_move_range);
+
   CPPUNIT_TEST_SUITE_END();
 
 public:
-  void setUp() {}
-  void tearDown() {}
-
   void test_basic();
   void test_erase();
   void test_find();
